pub fn vlq_decode(input: &[u8], pos: usize) -> Result<(i64, usize), DecodeError>Expand description
Decode a single VLQ value from the input bytes starting at the given position.
Returns (decoded_value, bytes_consumed) or a DecodeError.
pub fn vlq_decode(input: &[u8], pos: usize) -> Result<(i64, usize), DecodeError>Decode a single VLQ value from the input bytes starting at the given position.
Returns (decoded_value, bytes_consumed) or a DecodeError.